@@ -59,7 +59,7 @@ case "$switch" in
        echo -n $msg_press_enter_to_continue
        read
        echo "$msg_delimiter_star_line"
-       drbl-live.sh start
+       drbl-live.sh --prepare-ocsroot --skip-pause-in-the-end start
      fi
 
      echo "$msg_delimiter_star_line"
@@ -67,8 +67,16 @@ case "$switch" in
      echo "$msg_delimiter_star_line"
      sleep 1
      dcs clonezilla-start
+
+     echo "$msg_delimiter_star_line"
+     echo -n $msg_press_enter_to_continue
+     # force to use < /dev/stdin to avoid some bug about tftpd-hpa which will lock file handle 0.
+     read < /dev/stdin
      ;;
    "stop")
      drbl-ocs stop
+     echo "$msg_delimiter_star_line"
+     echo -n $msg_press_enter_to_continue
+     read < /dev/stdin
      ;;
 esac
